@@ -1,5 +1,6 @@
 NOEC <- function(x, expr, sigLev = 0.05){
 	# NOEC and LOEC calculation using Dunnett's test
+	## Dunnett, C.W., 1964. New tables for multiple comparisons with controls. Biometrics 30, 482-491
 	n <- nrow(expr)
 	m <- ncol(expr)
 	C <-  sum(expr)^2 / ((n + 1) * m) 
@@ -10,7 +11,7 @@ NOEC <- function(x, expr, sigLev = 0.05){
 	SW <- sqrt((SST - SSB) / ((n + 1) * (m - 1)))
 	tj <- (Tj / m) / (SW * sqrt(1 / m + 1 / m))
 	probF <- qf(1 - sigLev / 2, (n + 1) * (m - 1), n)
-	noecSign <- sign(tj - probF)
+	noecSign <- sign(abs(tj) - probF)
 	idx.one <- which(noecSign == -1)
 	if(length(idx.one) == 0) noec = NULL else noec = x[idx.one[length(idx.one)]]
 	idx.two <- which(noecSign == 1)
